@@ -16,7 +16,7 @@ from pypandoc.py3compat import path2url, string_types, unicode_type
 
 
 @contextlib.contextmanager
-def closed_tempfile(suffix, text=None, dir_name=None, check_case=False):
+def closed_tempfile(suffix, text=None, dir_name=None):
     file_name = None
     try:
         if dir_name:
@@ -27,10 +27,6 @@ def closed_tempfile(suffix, text=None, dir_name=None, check_case=False):
             if text:
                 test_file.write(text)
                 test_file.flush()
-        if check_case and file_name != file_name.lower():
-            # there is a bug in pandoc which can't work with uppercase lua files
-            # https://github.com/jgm/pandoc/issues/4610
-            raise unittest.SkipTest("pandoc has problems with uppercase filenames, got %s" % file_name)
         yield file_name
     finally:
         if dir_name:
@@ -74,7 +70,7 @@ def assert_produces_warning(expected_warning=Warning, filter_level="always",
     with warnings.catch_warnings(record=True) as w:
 
         if clear is not None:
-            # make sure that we are clearning these warnings
+            # make sure that we are clearing these warnings
             # if they have happened before
             # to guarantee that we will catch them
             if not is_list_like(clear):
@@ -118,6 +114,10 @@ def assert_produces_warning(expected_warning=Warning, filter_level="always",
 
 class TestPypandoc(unittest.TestCase):
 
+    # Python 2 compatibility
+    if not hasattr(unittest.TestCase, 'assertRaisesRegex'):
+        assertRaisesRegex = unittest.TestCase.assertRaisesRegexp
+
     def setUp(self):
         if 'HOME' not in os.environ:
             # if this is used with older versions of pandoc-citeproc
@@ -145,6 +145,18 @@ class TestPypandoc(unittest.TestCase):
         # according to http://pandoc.org/releases.html there were only two versions 0.x ...
         self.assertTrue(major in [0, 1, 2])
 
+    def test_ensure_pandoc_minimal_version(self):
+        assert "HOME" in os.environ, "No HOME set, this will error..."
+        assert pypandoc.ensure_pandoc_minimal_version(1) == True
+        assert pypandoc.ensure_pandoc_minimal_version(1,1) == True
+        assert pypandoc.ensure_pandoc_minimal_version(999,999) == False
+
+    def test_ensure_pandoc_maximal_version(self):
+        assert "HOME" in os.environ, "No HOME set, this will error..."
+        assert pypandoc.ensure_pandoc_maximal_version(999) == True
+        assert pypandoc.ensure_pandoc_maximal_version(999,999) == True
+        assert pypandoc.ensure_pandoc_maximal_version(1,1) == False
+
     def test_converts_valid_format(self):
         self.assertEqualExceptForNewlineEnd(pypandoc.convert_text("ok", format='md', to='rest'), 'ok')
 
@@ -152,13 +164,15 @@ class TestPypandoc(unittest.TestCase):
         def f():
             pypandoc.convert_text("ok", format='md', to='invalid')
 
-        self.assertRaises(RuntimeError, f)
+        with self.assertRaisesRegex(RuntimeError, "Invalid output format! Got invalid but "):
+            f()
 
     def test_does_not_convert_from_invalid_format(self):
         def f():
             pypandoc.convert_text("ok", format='invalid', to='rest')
 
-        self.assertRaises(RuntimeError, f)
+        with self.assertRaisesRegex(RuntimeError, 'Invalid input format! Got "invalid" but '):
+            f()
 
     def test_basic_conversion_from_file(self):
         with closed_tempfile('.md', text='# some title\n') as file_name:
@@ -187,8 +201,7 @@ class TestPypandoc(unittest.TestCase):
     def test_convert_with_custom_writer(self):
         lua_file_content = self.create_sample_lua()
         with closed_tempfile('.md', text='# title\n') as file_name:
-            with closed_tempfile('.lua', text=lua_file_content, dir_name="foo-bar+baz",
-                                 check_case=True) as lua_file_name:
+            with closed_tempfile('.lua', text=lua_file_content, dir_name="foo-bar+baz") as lua_file_name:
                 expected = u'<h1 id="title">title</h1>{0}'.format(os.linesep)
                 received = pypandoc.convert_file(file_name, lua_file_name)
                 self.assertEqualExceptForNewlineEnd(expected, received)
@@ -224,7 +237,7 @@ class TestPypandoc(unittest.TestCase):
         self.assertEqualExceptForNewlineEnd(expected_without_extension, received_without_extension)
 
     def test_conversion_from_markdown_with_extensions(self):
-        # Aparently without the extension, ~~ gets turned into different code
+        # Apparently without the extension, ~~ gets turned into different code
         # depending on the pandoc version. So we do not test for that anymore...
         input = u'~~strike~~'
         expected_with_extension = u'<p><del>strike</del></p>'
@@ -245,31 +258,8 @@ class TestPypandoc(unittest.TestCase):
             pypandoc.convert_text('# some title\n', to='odf', format='md',
                              outputfile=None)
 
-        self.assertRaises(RuntimeError, f)
-
-    def test_conversion_with_citeproc_filter(self):
-        # we just want to get a temp file name, where we can write to
-        filters = ['pandoc-citeproc']
-        written = pypandoc.convert_file('./filter_test.md', to='html', format='md',
-                                   outputfile=None, filters=filters)
-        import re as re
-        # only properly converted file will have this in it
-        found = re.search(r'Fenner', written)
-        self.assertTrue(found.group() == 'Fenner')
-        # only properly converted file will have this in it
-        found = re.search(r'10.1038', written)
-        self.assertTrue(found.group() == '10.1038')
-
-        # make sure that it splits the filter line
-        for filters in ['pandoc-citeproc', u'pandoc-citeproc']:
-            written = pypandoc.convert_file('./filter_test.md', to='html', format='md',
-                                       outputfile=None, filters=filters)
-            # only properly converted file will have this in it
-            found = re.search(r'Fenner', written)
-            self.assertTrue(found.group() == 'Fenner')
-            # only properly converted file will have this in it
-            found = re.search(r'10.1038', written)
-            self.assertTrue(found.group() == '10.1038')
+        with self.assertRaisesRegex(RuntimeError, "Invalid output format! Got odf but "):
+            f()
 
     def test_conversion_with_empty_filter(self):
         # we just want to get a temp file name, where we can write to
@@ -289,35 +279,36 @@ class TestPypandoc(unittest.TestCase):
         def f():
             pypandoc.convert_text('<h1>Primary Heading</h1>', 'md', format='html', extra_args=["--blah"])
 
-        self.assertRaises(RuntimeError, f)
+        with self.assertRaisesRegex(RuntimeError, 'Pandoc died with exitcode "6" during conversion: Unknown option --blah'):
+            f()
 
     def test_unicode_input(self):
         # make sure that pandoc always returns unicode and does not mishandle it
-        expected = u'üäöîôû{0}======{0}{0}'.format(os.linesep)
-        written = pypandoc.convert_text(u'<h1>üäöîôû</h1>', 'md', format='html')
+        expected = u'üäöîôû{0}'.format(os.linesep)
+        written = pypandoc.convert_text(u'<p>üäöîôû</p>', 'md', format='html')
         self.assertTrue(isinstance(written, unicode_type))
         self.assertEqualExceptForNewlineEnd(expected, written)
-        bytes = u'<h1>üäöîôû</h1>'.encode("utf-8")
+        bytes = u'<p>üäöîôû</p>'.encode("utf-8")
         written = pypandoc.convert_text(bytes, 'md', format='html')
-        self.assertEqualExceptForNewlineEnd(expected, written)
+        self.assertTrue(expected == written)
         self.assertTrue(isinstance(written, unicode_type))
 
-        # Only use german umlauts in th next test, as iso-8859-15 covers that
-        expected = u'üäö€{0}===={0}{0}'.format(os.linesep)
-        bytes = u'<h1>üäö€</h1>'.encode("iso-8859-15")
+        # Only use german umlauts in the next test, as iso-8859-15 covers that
+        expected = u'äüäö{0}'.format(os.linesep)
+        bytes = u'<p>äüäö</p>'.encode("iso-8859-15")
 
         # Without encoding, this fails as we expect utf-8 per default
 
         def f():
-            pypandoc.convert_text(bytes, 'md', format='html')
+            written = pypandoc.convert_text(bytes, 'md', format='html')
 
-        self.assertRaises(RuntimeError, f)
+            assert expected != written
 
         def f():
             # we have to use something which interprets '\xa4', so latin and -1 does not work :-/
-            pypandoc.convert_text(bytes, 'md', format='html', encoding="utf-16")
+            written = pypandoc.convert_text(bytes, 'md', format='html', encoding="utf-16")
 
-        self.assertRaises(RuntimeError, f)
+            assert expected != written
         # with the right encoding it should work...
         written = pypandoc.convert_text(bytes, 'md', format='html', encoding="iso-8859-15")
         self.assertEqualExceptForNewlineEnd(expected, written)
@@ -346,21 +337,24 @@ class TestPypandoc(unittest.TestCase):
             # needs an outputfile
             pypandoc.convert_text('# some title\n', to='pdf', format='md')
 
-        self.assertRaises(RuntimeError, f)
+        with self.assertRaisesRegex(RuntimeError, "Output to pdf only works by using a outputfile"):
+            f()
 
         # outputfile needs to end in pdf
         with closed_tempfile('.WRONG') as file_name:
             def f():
                 pypandoc.convert_text('# some title\n', to='pdf', format='md', outputfile=file_name)
 
-            self.assertRaises(RuntimeError, f)
+            with self.assertRaisesRegex(RuntimeError, 'PDF output needs an outputfile with ".pdf" as a fileending'):
+                f()
 
         # no extensions allowed
         with closed_tempfile('.pdf') as file_name:
             def f():
                 pypandoc.convert_text('# some title\n', to='pdf+somethign', format='md', outputfile=file_name)
 
-            self.assertRaises(RuntimeError, f)
+            with self.assertRaisesRegex(RuntimeError, r"PDF output can't contain any extensions: pdf\+somethign"):
+                f()
 
     def test_get_pandoc_path(self):
         result = pypandoc.get_pandoc_path()
@@ -378,7 +372,8 @@ class TestPypandoc(unittest.TestCase):
             pypandoc.convert_file(filepath, 'rst')
 
         for filepath in files:
-            self.assertRaises(RuntimeError, f, filepath)
+            with self.assertRaisesRegex(RuntimeError, "source_file is not a valid path"):
+                f(filepath)
 
     def test_convert_text_with_existing_file(self):
         with closed_tempfile('.md', text='# some title\n') as file_name:
